/*******************************************************************************

    This file is part of mDictionary.

    mDictionary is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    mDictionary is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with mDictionary.  If not, see <http://www.gnu.org/licenses/>.

    Copyright 2010 Comarch S.A.

*******************************************************************************/

/*!
    \file TranslationGoogle.cpp
    \brief Implementation of google plugin's translation.

    \author Jakub Jaszczynski <j.j.jaszczynski@gmail.com>
*/

#include "TranslationGoogle.h"

TranslationGoogle::TranslationGoogle():_key(QString("")),
                    _dictionaryInfo(QString("")), _trans(QString("")) {
    googlePlugin=0;
}

TranslationGoogle::TranslationGoogle(QString _key,QString _trans,
                    QString _dictionaryInfo,GooglePlugin *googlePlugin):
                     _key(_key),_dictionaryInfo(_dictionaryInfo), _trans(_trans) {
    this->googlePlugin=googlePlugin;
    if(googlePlugin)
        _dictHash = googlePlugin->hash();
    _bookmark=0;
}

TranslationGoogle::~TranslationGoogle(){
    ;
}

QString TranslationGoogle::key() const{
    return _key;
}

QString TranslationGoogle::toXml() const {
    QString result("");
    if(!googlePlugin)
        return result;   
    result="<dict> <info path=\"/usr/share/mdictionary/google.png\" ";
    if(isBookmark())
        result+=" bookmark=\"true\" > \n";
    else
        result+=" bookmark=\"false\" > \n";

    if(_trans!="")
        return result+=_dictionaryInfo+ "</info>"+_trans +"</dict>";
    QList<Translation*> translations=googlePlugin->searchWordList(_key);
    if(translations.size()>0 && translations.at(0)){
        if(isBookmark())
            translations.at(0)->setBookmark(true);
        return translations.at(0)->toXml();
    }
    return "";

}

void TranslationGoogle::setKey(QString) {
    this->_key=_key;
}

void TranslationGoogle::setDictionaryInfo(QString){
    this->_dictionaryInfo=_dictionaryInfo;
}
