/*******************************************************************************

    This file is part of mDictionary.

    mDictionary is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    mDictionary is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with mDictionary.  If not, see <http://www.gnu.org/licenses/>.

    Copyright 2010 Comarch S.A.

*******************************************************************************/
/*!
    \file CompressedReader.h
    \brief Class implementing StarDictReader interface and handling reading from compressed
    files like .gz or .dz

    \author Mateusz Półrola
*/

#ifndef COMPRESSEDREADER_H
#define COMPRESSEDREADER_H

#include <QObject>
#include <zconf.h>
//#include <zlibdefs.h>
#include <zlib.h>
#include "StarDictReader.h"

/*!
    Class implementing StarDictReader interface and handling reading from compressed
    files like .gz or .dz, using zlib
*/
class CompressedReader : public StarDictReader
{
    Q_OBJECT
public:
    CompressedReader(QObject *parent = 0);

    //! Creates new compressed reader and open file with passed filename
    CompressedReader(QString filename, QObject *parent = 0);

    //! Destructs object and closing file
    ~CompressedReader();

    /*!
        Reads translations text from compressed dict file.
        \param offset 64-bit offset of translation in uncompressed file, readed
             from idx file
        \param len length of uncompressed translation, readed from idx file too
    */
    QByteArray readString(qint64 offset, qint32 len);

    /*!
        Reads 32-bits integer value from compressed file and convert it from
        BigEndian to Little Endian
    */
    qint32 readInt32BigEndian();

    /*!
        Reads 64-bits integer value from compressed file and convert it from
        BigEndian to Little Endian
    */
    qint64 readInt64BigEndian();

    /*!
        Reads single string from compressed file, end of string is marked as '\0'
        in file.
    */
    QString readKeyword();


    //! Closing file;
    void close();

protected:
    /*!
        Opens file
        \returns true if file is opened or false otherwise
    */
    bool open(QString file);

    //! Reads single char from compressed.
    QChar readChar();

private:
    gzFile _file;
};

#endif // COMPRESSEDREADER_H
