/*******************************************************************************

    This file is part of mDictionary.

    mDictionary is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    mDictionary is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with mDictionary.  If not, see <http://www.gnu.org/licenses/>.

    Copyright 2010 Comarch S.A.

*******************************************************************************/
/*!
   \file DictsModel.h
   \brief Item model for informations about xdxf dictionaries.

   \author Mateusz Półrola <mateusz.polrola@comarch.pl>
*/

#ifndef DICTSMODEL_H
#define DICTSMODEL_H


#include <QAbstractItemModel>
#include "DownloadDict.h"


/*!
  Item model for informations about xdxf dictionaries.
  Contains informations about languages of dictionary, it's name, size and
 download link. Download link is stored as UserRole, and not displayed in views
 using this model.
*/
class DictsModel : public QAbstractItemModel
{
    Q_OBJECT
public:
    /*!
        Constructor
        \param dicts list of DownloadDict objects, each such object describes
        one dictionary
    */
    DictsModel(QList<DownloadDict> dicts, QObject *parent);

    //! \return return numner of rows
    int rowCount(const QModelIndex &parent = QModelIndex()) const;

    //! \return return numner of columns
    int columnCount(const QModelIndex &parent = QModelIndex()) const;

    //!  create Index,  createIndex(row,column,row)
    QModelIndex index(int row, int column, const QModelIndex &parent = QModelIndex()) const;

    //! return new QModelIndex;
    QModelIndex parent(const QModelIndex &child) const;

    /*!
        \return return empty QVariant when role is't DisplayRole,
        else return QVariant (QString with _from,_to,_title)
    */
    QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const;

    //! \return return a QVariant with header QString.
    QVariant headerData(int section, Qt::Orientation orientation, int role) const;

private:
    QList<DownloadDict> dicts;
};

#endif // DICTSMODEL_H
